@@ -12,24 +12,12 @@ def login_handler(sketch: Sketch):
         )
         sketch.add_extensions("auth")
 
-        sketch.write_template(
-            "commands_default_tpl",
-            templates.commands,
-            pjoin(sketch.app_folder, "commands", "__init__.py",),
-        )
-
         sketch.write_template(
             "ext_login_tpl",
             templates.ext,
             pjoin(sketch.app_folder, "ext", "auth.py"),
         )
 
-        sketch.write_template(
-            "models_login_tpl",
-            templates.models,
-            pjoin(sketch.app_folder, "models", "user.py"),
-        )
-
         sketch.write_template(
             "examples_login_auth_tpl",
             templates.examples,
@@ -132,25 +120,17 @@ def security_web_handler(sketch: Sketch):
             pjoin(sketch.app_folder, "site", "views.py"),
         )
 
-        sketch.write_template(
-            "security_web_only_tpl",
-            templates.commands,
-            pjoin(sketch.app_folder, "commands", "__init__.py",),
-            mode="w",
-        )
+        if sketch.database == "mongodb":
+            auth_tpl = "ext_auth_security_mongo_tpl"
+        else:
+            auth_tpl = "ext_security_web_only_tpl"
 
         sketch.write_template(
-            "ext_security_web_only_tpl",
+            auth_tpl,
             templates.ext,
             pjoin(sketch.app_folder, "ext", "auth.py"),
         )
 
-        sketch.write_template(
-            "models_security_tpl",
-            templates.models,
-            pjoin(sketch.app_folder, "models", "user.py"),
-        )
-
         sketch.write_template(
             "examples_security_auth_tpl",
             templates.examples,
@@ -188,13 +168,6 @@ def none_handler(sketch: Sketch):
             pjoin(sketch.app_folder, "site", "views.py"),
         )
 
-        if not sketch.api_auth_framework == "none":
-            sketch.write_template(
-                "no_auth_tpl",
-                templates.commands,
-                pjoin(sketch.app_folder, "commands", "__init__.py",),
-            )
-
         return True
 
 
@@ -205,9 +178,10 @@ class AuthHandler(GenericHandler):
             if r:
                 if not handler.__name__ == "none_handler":
                     sketch.write_template(
-                        "models_auth_tpl",
+                        "models_init_tpl",
                         templates.models,
                         pjoin(sketch.app_folder, "models", "__init__.py",),
+                        mode="w",
                     )
                 return r
 
